@@ -187,6 +187,7 @@ impl UnixTerminal {
                 Ok(())
             })
             .unwrap_or(()); // ignore write errors
+        self.drain().count(); // drain pending events
 
         // disable signal handler
         self.signal_delivery.handle().close();
@@ -361,6 +362,10 @@ impl Terminal for UnixTerminal {
     fn frames_drop(&mut self) {
         self.write_queue.clear_but_last()
     }
+
+    fn dyn_ref(&mut self) -> &mut dyn Terminal {
+        self
+    }
 }
 
 /// Guard against EAGAIN and EINTR
